@@ -13,7 +13,7 @@
 
 """oslo.i18n integration module.
 
-See http://docs.openstack.org/developer/oslo.i18n/usage.html
+See https://docs.openstack.org/oslo.i18n/latest/user/index.html .
 
 """
 
@@ -29,13 +29,3 @@ _translators = oslo_i18n.TranslatorFactory(domain='python-troveclient')
 
 # The primary translation function using the well-known name "_"
 _ = _translators.primary
-
-# Translators for log levels.
-#
-# The abbreviated names are meant to reflect the usual use of a short
-# name like '_'. The "L" is for "log" and the other letter comes from
-# the level.
-_LI = _translators.log_info
-_LW = _translators.log_warning
-_LE = _translators.log_error
-_LC = _translators.log_critical
