@@ -12,11 +12,11 @@
 
 from unittest import mock
 
-from osc_lib import exceptions
 from osc_lib import utils
 from oslo_utils import uuidutils
 
 from troveclient import common
+from troveclient import exceptions
 from troveclient.osc.v1 import database_instances
 from troveclient.tests.osc.v1 import fakes
 from troveclient.v1 import instances
@@ -41,10 +41,34 @@ class TestInstanceList(TestInstances):
     def setUp(self):
         super(TestInstanceList, self).setUp()
         self.cmd = database_instances.ListDatabaseInstances(self.app, None)
-        self.data = self.fake_instances.get_instances()
 
     def test_instance_list_defaults(self):
-        self.instance_client.list.return_value = common.Paginated(self.data)
+        instance_id = self.random_uuid()
+        name = self.random_name('test-list')
+        tenant_id = self.random_uuid()
+        insts = [
+            {
+                "id": instance_id,
+                "name": name,
+                "status": "ACTIVE",
+                "operating_status": "HEALTHY",
+                "addresses": [
+                    {"type": "private", "address": "10.0.0.13"}
+                ],
+                "volume": {"size": 2},
+                "flavor": {"id": "02"},
+                "region": "regionOne",
+                "datastore": {
+                    "version": "5.6", "type": "mysql",
+                    "version_number": "5.7.29"
+                },
+                "tenant_id": tenant_id,
+                "replica_of": self.random_uuid(),
+                "access": {"is_public": False, "allowed_cidrs": []},
+            }
+        ]
+        self.instance_client.list.return_value = common.Paginated(
+            [instances.Instance(mock.MagicMock(), inst) for inst in insts])
 
         parsed_args = self.check_parser(self.cmd, [], [])
         columns, data = self.cmd.take_action(parsed_args)
@@ -56,21 +80,47 @@ class TestInstanceList(TestInstances):
         )
 
         values = [
-            ('1234', 'test-member-1', 'mysql', '5.6', 'ACTIVE', False,
+            (instance_id, name, 'mysql', '5.6', 'ACTIVE', 'HEALTHY', False,
              [{"type": "private", "address": "10.0.0.13"}],
              '02', 2, 'replica'),
-            ('5678', 'test-member-2', 'mysql', '5.6', 'ACTIVE', False,
-             [{"type": "private", "address": "10.0.0.14"}],
-             '2', 2, '')
         ]
         self.assertEqual(values, data)
 
     def test_instance_list_all_projects(self):
-        self.mgmt_client.list.return_value = common.Paginated(self.data)
+        instance_id = self.random_uuid()
+        name = self.random_name('test-list')
+        tenant_id = self.random_uuid()
+        server_id = self.random_uuid()
+        insts = [
+            {
+                "id": instance_id,
+                "name": name,
+                "status": "ACTIVE",
+                "operating_status": "HEALTHY",
+                "addresses": [
+                    {"type": "private", "address": "10.0.0.13"}
+                ],
+                "volume": {"size": 2},
+                "flavor": {"id": "02"},
+                "region": "regionOne",
+                "datastore": {
+                    "version": "5.6", "type": "mysql",
+                    "version_number": "5.7.29"
+                },
+                "tenant_id": tenant_id,
+                "access": {"is_public": False, "allowed_cidrs": []},
+                "server_id": server_id,
+                'server': {
+                    'id': server_id
+                }
+            }
+        ]
+        self.mgmt_client.list.return_value = common.Paginated(
+            [instances.Instance(mock.MagicMock(), inst) for inst in insts])
 
         parsed_args = self.check_parser(self.cmd, ["--all-projects"],
                                         [("all_projects", True)])
-        columns, instances = self.cmd.take_action(parsed_args)
+        columns, data = self.cmd.take_action(parsed_args)
 
         self.mgmt_client.list.assert_called_once_with(**self.defaults)
         self.assertEqual(
@@ -79,34 +129,82 @@ class TestInstanceList(TestInstances):
         )
 
         expected_instances = [
-            ('1234', 'test-member-1', 'mysql', '5.6',
-             'ACTIVE', False, [{"type": "private", "address": "10.0.0.13"}],
-             '02', 2, 'replica', 'fake_tenant_id'),
-            ('5678', 'test-member-2', 'mysql', '5.6',
-             'ACTIVE', False, [{"type": "private", "address": "10.0.0.14"}],
-             '2', 2, '', 'fake_tenant_id')
+            (instance_id, name, 'mysql', '5.6', 'ACTIVE', 'HEALTHY', False,
+             [{"type": "private", "address": "10.0.0.13"}],
+             '02', 2, '', server_id, tenant_id),
         ]
-        self.assertEqual(expected_instances, instances)
+        self.assertEqual(expected_instances, data)
+
+    def test_instance_list_for_project(self):
+        instance_id = self.random_uuid()
+        name = self.random_name('test-list')
+        tenant_id = self.random_uuid()
+        server_id = self.random_uuid()
+        insts = [
+            {
+                "id": instance_id,
+                "name": name,
+                "status": "ACTIVE",
+                "operating_status": "HEALTHY",
+                "addresses": [
+                    {"type": "private", "address": "10.0.0.13"}
+                ],
+                "volume": {"size": 2},
+                "flavor": {"id": "02"},
+                "region": "regionOne",
+                "datastore": {
+                    "version": "5.6", "type": "mysql",
+                    "version_number": "5.7.29"
+                },
+                "tenant_id": tenant_id,
+                "access": {"is_public": False, "allowed_cidrs": []},
+                "server_id": server_id,
+                'server': {
+                    'id': server_id
+                }
+            }
+        ]
+        self.mgmt_client.list.return_value = common.Paginated(
+            [instances.Instance(mock.MagicMock(), inst) for inst in insts])
+
+        parsed_args = self.check_parser(self.cmd, ["--project-id", tenant_id],
+                                        [("project_id", tenant_id)])
+        columns, data = self.cmd.take_action(parsed_args)
+
+        self.assertEqual(
+            database_instances.ListDatabaseInstances.admin_columns,
+            columns
+        )
+        expected_instances = [
+            (instance_id, name, 'mysql', '5.6', 'ACTIVE', 'HEALTHY', False,
+             [{"type": "private", "address": "10.0.0.13"}],
+             '02', 2, '', server_id, tenant_id),
+        ]
+        self.assertEqual(expected_instances, data)
+
+        expected_params = {
+            'include_clustered': False,
+            'limit': None,
+            'marker': None,
+            'project_id': tenant_id
+        }
+        self.mgmt_client.list.assert_called_once_with(**expected_params)
 
 
 class TestInstanceShow(TestInstances):
-    values = ([{'address': '10.0.0.13', 'type': 'private'}], [], 'mysql',
-              '5.6', '02', '1234', 'test-member-1', False, 'regionOne',
-              'fake_master_id', 'ACTIVE', 'fake_tenant_id', 2)
-
     def setUp(self):
         super(TestInstanceShow, self).setUp()
         self.cmd = database_instances.ShowDatabaseInstance(self.app, None)
-        self.data = self.fake_instances.get_instances_1234()
-        self.instance_client.get.return_value = self.data
         self.columns = (
             'addresses',
             'allowed_cidrs',
             'datastore',
             'datastore_version',
+            'datastore_version_number',
             'flavor',
             'id',
             'name',
+            'operating_status',
             'public',
             'region',
             'replica_of',
@@ -116,11 +214,42 @@ class TestInstanceShow(TestInstances):
         )
 
     def test_show(self):
-        args = ['1234']
-        parsed_args = self.check_parser(self.cmd, args, [])
+        instance_id = self.random_uuid()
+        name = self.random_name('test-show')
+        flavor_id = self.random_uuid()
+        primary_id = self.random_uuid()
+        tenant_id = self.random_uuid()
+        inst = {
+            "id": instance_id,
+            "name": name,
+            "status": "ACTIVE",
+            "operating_status": "HEALTHY",
+            "addresses": [
+                {"type": "private", "address": "10.0.0.13"}
+            ],
+            "volume": {"size": 2},
+            "flavor": {"id": flavor_id},
+            "region": "regionOne",
+            "datastore": {
+                "version": "5.7.29", "type": "mysql",
+                "version_number": "5.7.29"
+            },
+            "tenant_id": tenant_id,
+            "replica_of": {'id': primary_id},
+            "access": {"is_public": False, "allowed_cidrs": []},
+        }
+        self.instance_client.get.return_value = instances.Instance(
+            mock.MagicMock(), inst)
+
+        parsed_args = self.check_parser(self.cmd, [instance_id], [])
         columns, data = self.cmd.take_action(parsed_args)
+
+        values = ([{'address': '10.0.0.13', 'type': 'private'}], [], 'mysql',
+                  '5.7.29', '5.7.29', flavor_id, instance_id, name, 'HEALTHY',
+                  False, 'regionOne', primary_id, 'ACTIVE',
+                  tenant_id, 2)
         self.assertEqual(self.columns, columns)
-        self.assertEqual(self.values, data)
+        self.assertEqual(values, data)
 
 
 class TestDatabaseInstanceDelete(TestInstances):
@@ -181,13 +310,14 @@ class TestDatabaseInstanceDelete(TestInstances):
 
 class TestDatabaseInstanceCreate(TestInstances):
 
-    values = ('2017-12-22T20:02:32', 'mysql', '5.6', '310',
+    values = ('2017-12-22T20:02:32', 'mysql', '5.6', '5.7.29', '310',
               '2468', 'test', 'test-net', 'net-id', 'BUILD',
               '2017-12-22T20:02:32', 1)
     columns = (
         'created',
         'datastore',
         'datastore_version',
+        'datastore_version_number',
         'flavor',
         'id',
         'name',
@@ -206,7 +336,6 @@ class TestDatabaseInstanceCreate(TestInstances):
 
     @mock.patch.object(utils, 'find_resource')
     def test_instance_create(self, mock_find):
-        mock_find.id.side_effect = ['test', 'mod_id']
         args = ['test-name', '--flavor', '103',
                 '--size', '1',
                 '--databases', 'db1', 'db2',
@@ -240,7 +369,8 @@ class TestDatabaseInstanceCreate(TestInstances):
         self.assertEqual(self.columns, columns)
         self.assertEqual(self.values, data)
 
-    def test_instance_create_without_allowed_cidrs(self):
+    @mock.patch.object(utils, 'find_resource')
+    def test_instance_create_without_allowed_cidrs(self, mock_find):
         resp = {
             "id": "a1fea1cf-18ad-48ab-bdfd-fce99a4b834e",
             "name": "test-mysql",
@@ -250,7 +380,8 @@ class TestDatabaseInstanceCreate(TestInstances):
             },
             "datastore": {
                 "type": "mysql",
-                "version": "5.7.29"
+                "version": "5.7.29",
+                "version_number": "5.7.29"
             },
             "region": "RegionOne",
             "access": {
@@ -294,6 +425,7 @@ class TestDatabaseInstanceCreate(TestInstances):
             'created',
             'datastore',
             'datastore_version',
+            'datastore_version_number',
             'flavor',
             'id',
             'name',
@@ -309,6 +441,7 @@ class TestDatabaseInstanceCreate(TestInstances):
             "2020-08-12T09:41:47",
             "mysql",
             "5.7.29",
+            "5.7.29",
             "a48ea749-7ee3-4003-8aae-eb4e79773e2d",
             "a1fea1cf-18ad-48ab-bdfd-fce99a4b834e",
             "test-mysql",
@@ -322,7 +455,10 @@ class TestDatabaseInstanceCreate(TestInstances):
         self.assertEqual(expected_columns, columns)
         self.assertEqual(expected_values, data)
 
-    def test_instance_create_nic_param(self):
+    @mock.patch.object(utils, 'find_resource')
+    def test_instance_create_nic_param(self, mock_find):
+        fake_id = self.random_uuid()
+        mock_find.return_value.id = fake_id
         args = [
             'test-mysql',
             '--flavor', 'a48ea749-7ee3-4003-8aae-eb4e79773e2d',
@@ -336,7 +472,7 @@ class TestDatabaseInstanceCreate(TestInstances):
 
         self.instance_client.create.assert_called_once_with(
             'test-mysql',
-            flavor_id='a48ea749-7ee3-4003-8aae-eb4e79773e2d',
+            flavor_id=fake_id,
             volume={"size": 1, "type": None},
             databases=[],
             users=[],
@@ -344,6 +480,7 @@ class TestDatabaseInstanceCreate(TestInstances):
             availability_zone=None,
             datastore='mysql',
             datastore_version='5.7.29',
+            datastore_version_number=None,
             nics=[
                 {'network_id': 'net1', 'subnet_id': 'subnet_id',
                  'ip_address': '192.168.1.11'}
@@ -385,14 +522,15 @@ class TestDatabaseInstanceResizeFlavor(TestInstances):
     @mock.patch.object(utils, 'find_resource')
     def test_instance_resize_flavor(self, mock_find):
         args = ['instance1', 'flavor_id']
-        mock_find.return_value = 'fake_instance_id'
-
+        mock_find.side_effect = [
+            mock.MagicMock(id='fake_instance_id'),
+            mock.MagicMock(id='fake_flavor_id')
+        ]
         parsed_args = self.check_parser(self.cmd, args, [])
-        result = self.cmd.take_action(parsed_args)
+        self.cmd.take_action(parsed_args)
 
         self.instance_client.resize_instance.assert_called_with(
-            'fake_instance_id', 'flavor_id')
-        self.assertIsNone(result)
+            'fake_instance_id', 'fake_flavor_id')
 
 
 class TestDatabaseInstanceUpgrade(TestInstances):
@@ -565,7 +703,7 @@ class TestInstanceReplicaDetach(TestInstances):
         mock_find.return_value = args[0]
         parsed_args = self.check_parser(self.cmd, args, [])
         result = self.cmd.take_action(parsed_args)
-        self.instance_client.edit.assert_called_with(
+        self.instance_client.update.assert_called_with(
             'instance', detach_replica_source=True)
         self.assertIsNone(result)
 
