@@ -15,7 +15,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import mock
+from unittest import mock
+
 import testtools
 
 from troveclient import base
@@ -84,8 +85,7 @@ class InstancesTest(testtools.TestCase):
         super(InstancesTest, self).tearDown()
         instances.Instances.__init__ = self.orig__init
 
-    @mock.patch('warnings.warn')
-    def test_create(self, mock_warn):
+    def test_create(self):
         def side_effect_func(path, body, inst):
             return path, body, inst
 
@@ -95,10 +95,11 @@ class InstancesTest(testtools.TestCase):
                                         ['db1', 'db2'], ['u1', 'u2'],
                                         datastore="datastore",
                                         datastore_version="datastore-version",
-                                        nics=nics, slave_of='test',
+                                        nics=nics, replica_of='test',
                                         replica_count=4,
                                         modules=['mod_id'],
-                                        locality='affinity')
+                                        locality='affinity',
+                                        access={'is_public': True})
         self.assertEqual("/instances", p)
         self.assertEqual("instance", i)
         self.assertEqual(['db1', 'db2'], b["instance"]["databases"])
@@ -110,14 +111,11 @@ class InstancesTest(testtools.TestCase):
                          b["instance"]["datastore"]["version"])
         self.assertEqual(nics, b["instance"]["nics"])
         self.assertEqual(103, b["instance"]["flavorRef"])
-        # Assert that slave_of is not used and if specified, there is a warning
-        # and it's value is used for replica_of.
         self.assertEqual('test', b['instance']['replica_of'])
-        self.assertNotIn('slave_of', b['instance'])
-        self.assertTrue(mock_warn.called)
         self.assertEqual([{'id': 'mod_id'}], b["instance"]["modules"])
         self.assertEqual(4, b["instance"]["replica_count"])
         self.assertEqual('affinity', b["instance"]["locality"])
+        self.assertEqual({'is_public': True}, b["instance"]["access"])
 
     def test_list(self):
         page_mock = mock.Mock()
@@ -129,6 +127,16 @@ class InstancesTest(testtools.TestCase):
         page_mock.assert_called_with("/instances", "instances", limit, marker,
                                      include_clustered)
 
+    def test_detailed_list(self):
+        page_mock = mock.Mock()
+        self.instances._paginated = page_mock
+        limit = "test-limit"
+        marker = "test-marker"
+        include_clustered = {'include_clustered': False}
+        self.instances.list(limit, marker, detailed=True)
+        page_mock.assert_called_with("/instances/detail", "instances", limit,
+                                     marker, include_clustered)
+
     def test_get(self):
         def side_effect_func(path, inst):
             return path, inst
@@ -216,27 +224,55 @@ class InstancesTest(testtools.TestCase):
         resp.status_code = 500
         self.assertRaises(Exception, self.instances.modify, 'instance1')
 
-    def test_edit(self):
+    def test_module_apply(self):
         resp = mock.Mock()
-        resp.status_code = 204
-
-        def fake_patch(url, body):
-            # Make sure we never pass slave_of to the API.
-            self.assertIn('instance', body)
-            self.assertNotIn('slave_of', body['instance'])
-            return resp, None
-
-        self.instances.api.client.patch = mock.Mock(side_effect=fake_patch)
-        self.instances.edit(123)
-        self.instances.edit(123, 321)
-        self.instances.edit(123, 321, 'name-1234')
-        self.instances.edit(123, 321, 'name-1234', True)
-        self.instances.edit(self.instance_with_id)
-        self.instances.edit(self.instance_with_id, 123)
-        self.instances.edit(self.instance_with_id, 123, 'name-1234')
-        self.instances.edit(self.instance_with_id, 123, 'name-1234', True)
+        resp.status_code = 200
+        body = {'modules': []}
+        self.instances.api.client.post = mock.Mock(return_value=(resp, body))
+        self.instances.module_apply(self.instance_with_id, "mod_id")
         resp.status_code = 500
-        self.assertRaises(Exception, self.instances.edit, 'instance1')
+        self.assertRaises(Exception, self.instances.module_apply,
+                          'instance1', 'mod1')
+
+    def test_module_remove(self):
+        resp = mock.Mock()
+        resp.status_code = 200
+        body = {'modules': []}
+        self.instances.api.client.delete = mock.Mock(return_value=(resp, body))
+        self.instances.module_remove(self.instance_with_id, "mod_id")
+        resp.status_code = 500
+        self.assertRaises(Exception, self.instances.module_remove,
+                          'instance1', 'mod1')
+
+    def test_module_query(self):
+        resp = mock.Mock()
+        resp.status_code = 200
+        body = {'modules': []}
+        self.instances.api.client.get = mock.Mock(return_value=(resp, body))
+        self.instances.module_query(self.instance_with_id)
+        resp.status_code = 500
+        self.assertRaises(Exception, self.instances.module_query,
+                          'instance1')
+
+    def test_module_retrieve(self):
+        resp = mock.Mock()
+        resp.status_code = 200
+        body = {'modules': []}
+        self.instances.api.client.get = mock.Mock(return_value=(resp, body))
+        self.instances.module_retrieve(self.instance_with_id)
+        resp.status_code = 500
+        self.assertRaises(Exception, self.instances.module_retrieve,
+                          'instance1')
+
+    def test_module_list_instance(self):
+        resp = mock.Mock()
+        resp.status_code = 200
+        body = {'modules': []}
+        self.instances.api.client.get = mock.Mock(return_value=(resp, body))
+        self.instances.modules(self.instance_with_id)
+        resp.status_code = 500
+        self.assertRaises(Exception, self.instances.modules,
+                          'instance1')
 
     def test_upgrade(self):
         resp = mock.Mock()
