@@ -165,6 +165,38 @@ class ManagementTest(testtools.TestCase):
         self.assertEqual({'reset-task-status': {}}, self.body_)
 
 
+class MgmtFlavorsTest(testtools.TestCase):
+
+    def setUp(self):
+        super(MgmtFlavorsTest, self).setUp()
+        self.orig__init = management.MgmtFlavors.__init__
+        management.MgmtFlavors.__init__ = mock.Mock(return_value=None)
+        self.flavors = management.MgmtFlavors()
+        self.flavors.api = mock.Mock()
+        self.flavors.api.client = mock.Mock()
+        self.flavors.resource_class = mock.Mock(return_value="flavor-1")
+        self.orig_base_getid = base.getid
+        base.getid = mock.Mock(return_value="flavor1")
+
+    def tearDown(self):
+        super(MgmtFlavorsTest, self).tearDown()
+        management.MgmtFlavors.__init__ = self.orig__init
+        base.getid = self.orig_base_getid
+
+    def test_create(self):
+        def side_effect_func(path, body, inst):
+            return path, body, inst
+
+        self.flavors._create = mock.Mock(side_effect=side_effect_func)
+        p, b, i = self.flavors.create("test-name", 1024, 30, 2, 1)
+        self.assertEqual("/mgmt/flavors", p)
+        self.assertEqual("flavor", i)
+        self.assertEqual("test-name", b["flavor"]["name"])
+        self.assertEqual(1024, b["flavor"]["ram"])
+        self.assertEqual(2, b["flavor"]["vcpu"])
+        self.assertEqual(1, b["flavor"]["flavor_id"])
+
+
 class MgmtDatastoreVersionsTest(testtools.TestCase):
 
     def setUp(self):
@@ -203,12 +235,15 @@ class MgmtDatastoreVersionsTest(testtools.TestCase):
         self.ds_version._create = mock.Mock(side_effect=side_effect_func)
         p, b, = self.ds_version.create(
             "ds-version1", "mysql", "mysql", "image-id",
-            ["mysql-server-5.5"], "true", "true")
+            ["mysql-server-5.5"], "registry-ext",
+            "repl-strategy", "true", "true")
         self.assertEqual("/mgmt/datastore-versions", p)
         self.assertEqual("ds-version1", b["version"]["name"])
         self.assertEqual("mysql", b["version"]["datastore_name"])
         self.assertEqual("mysql", b["version"]["datastore_manager"])
         self.assertEqual("image-id", b["version"]["image"])
+        self.assertEqual("registry-ext", b["version"]["registry_ext"])
+        self.assertEqual("repl-strategy", b["version"]["repl_strategy"])
         self.assertEqual(["mysql-server-5.5"], b["version"]["packages"])
         self.assertTrue(b["version"]["active"])
         self.assertTrue(b["version"]["default"])
